@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 # ******************************************************************
 # * Software: resumify - testing                                   *
-# * Version:  1.1                                                  *
+# * Version:  1.1.4                                                *
 # * License:  MIT License                                          *
 # *                                                                *
 # * Maintainer:  Devansh Soni (sonidev0201@gmail.com)              *
@@ -31,17 +31,28 @@ class TwoColumnTemplate(FPDF):
         self.hr_sep_pos = 32
         self.name_size = 32
         self.heading_size = 14
+        self.main_text_size = 11
+        self.medium_text_size = 10
+        self.desc_text_size = 9
+        self.links_text_size = 10
         self.border_val = 0
         self.underline_heads = ''
+        self.head_lines = True
+        self.capitalize_head = True
+        self.heading_color = (10, 77, 122)
         self.add_page()
 
         # Add ubuntu fonts
-        self.add_font('Ubuntu-LightItalic', '', os.path.join(BASE_DIR, 'TrashFiles/fonts/Ubuntu/Ubuntu-LightItalic.ttf'), uni=True)
-        self.add_font('Ubuntu-Light', '', os.path.join(BASE_DIR, 'TrashFiles/fonts/Ubuntu/Ubuntu-Light.ttf'), uni=True)
-        self.add_font('Ubuntu', '', os.path.join(BASE_DIR, 'TrashFiles/fonts/Ubuntu/Ubuntu-Regular.ttf'), uni=True)
+        self.add_font('Ubuntu-LightItalic', '', os.path.join(BASE_DIR, 'resumify/fonts/Ubuntu/Ubuntu-LightItalic.ttf'), uni=True)
+        self.add_font('Ubuntu-Light', '', os.path.join(BASE_DIR, 'resumify/fonts/Ubuntu/Ubuntu-Light.ttf'), uni=True)
+        self.add_font('Ubuntu-Bold', '', os.path.join(BASE_DIR, 'resumify/fonts/Ubuntu/Ubuntu-Bold.ttf'), uni=True)
+        self.add_font('Ubuntu-Medium', '', os.path.join(BASE_DIR, 'resumify/fonts/Ubuntu/Ubuntu-Medium.ttf'), uni=True)
+        self.add_font('Ubuntu', '', os.path.join(BASE_DIR, 'resumify/fonts/Ubuntu/Ubuntu-Regular.ttf'), uni=True)
 
         # Set fonts
         self.lightFont = 'Ubuntu-Light'
+        self.boldFont = 'Ubuntu-Bold'
+        self.mediumFont = 'Ubuntu-Medium'
         self.lightItalicFont = 'Ubuntu-LightItalic'
         self.regularFont = 'Ubuntu'
 
@@ -69,22 +80,30 @@ class TwoColumnTemplate(FPDF):
     def create_head(self, pos, title):
         "Inserts heading to the page"
 
+        if self.capitalize_head is True:
+            title = title.upper()
+        else:
+            title = title.title()
+
         self.initPosition(pos)
-        self.set_text_color(30, 30, 90)
-        self.set_draw_color(30, 30, 90)
+        self.set_text_color(*self.heading_color)
+        self.set_draw_color(*self.heading_color)
         self.set_line_width(0.3)
-        self.set_font(self.regularFont, self.underline_heads, self.heading_size)
+        self.set_font(self.mediumFont, self.underline_heads, self.heading_size)
 
         if pos == 1:
             self.initPositionX(pos)
-            self.cell(self.main_wid, 12, txt=title.title(), border='', ln=1, align="L")
+            self.cell(self.main_wid, 12, txt=title, border='', ln=1, align="L")
             self.main_y = self.get_y()
-            self.line(self.side_wid+20+self.get_string_width(title)+2, self.get_y()-4.8, self.main_wid+self.side_wid+20, self.get_y()-4.8)
+            if self.head_lines:
+                self.line(self.side_wid+20+self.get_string_width(title)+2, self.get_y()-4.8, self.main_wid+self.side_wid+20, self.get_y()-4.8)
+
         elif pos == 0:
             self.initPositionX(pos)
-            self.cell(self.side_wid, 12, txt=title.title(), border='', ln=1, align="L")
+            self.cell(self.side_wid, 12, txt=title, border='', ln=1, align="L")
             self.side_y = self.get_y()
-            self.line(10+self.get_string_width(title)+2, self.get_y()-4.8, self.side_wid+10, self.get_y()-4.8)
+            if self.head_lines:
+                self.line(10+self.get_string_width(title)+2, self.get_y()-4.8, self.side_wid+10, self.get_y()-4.8)
 
         self.set_text_color(0, 0, 0)
 
@@ -131,16 +150,17 @@ class TwoColumnTemplate(FPDF):
             self.set_font(self.regularFont, '', self.name_size)
 
         c1w = math.ceil(((self.ttl_wid - self.get_string_width(fname+" "+lname))/2) + self.get_string_width(fname+" ")) - 1
-        self.cell(c1w, 13, txt=fname, border=self.border_val, ln=0, align="R")
+        self.cell(c1w, 13, txt=fname.title(), border=self.border_val, ln=0, align="R")
         self.cell(1, 13, txt="", border=self.border_val, ln=0, align="R")
 
         self.set_font(self.lightFont, '', self.name_size)
         if bolds[1]:
             self.set_font(self.regularFont, '', self.name_size)
 
-        self.cell(self.ttl_wid-c1w-1, 13, txt=lname, border=self.border_val, ln=1, align="L")
+        self.cell(self.ttl_wid-c1w-1, 13, txt=lname.title(), border=self.border_val, ln=1, align="L")
 
-        self.set_font(self.regularFont, '', 10)
+        # self.set_text_color(*self.heading_color)
+        self.set_font(self.regularFont, '', self.medium_text_size)
         self.cell(self.ttl_wid, 5, txt=contact_info, border=self.border_val, ln=1, align="C")
         self.line(0, self.hr_sep_pos, 210, self.hr_sep_pos);
         self.set_text_color(0, 0, 0)
@@ -151,22 +171,31 @@ class TwoColumnTemplate(FPDF):
         "Add links to your profiles on Github, LinkedIn, Twitter or your personal website"
 
         self.set_y(self.hr_sep_pos+1)
-        ot = self.ttl_wid/3 - 9
+        ot = self.ttl_wid/3 - 11
         vals = list(links.items())[:6]
 
         for i in range(0, len(vals), 3):
+            if len(vals[i:i+3]) > 1:
+                gap = (self.ttl_wid - sum([self.get_string_width(k+" : "+v[0])+2 for k, v in vals[i:i+3]]))/(len(vals[i:i+3])-1)
+            else:
+                gap = (self.ttl_wid - sum([self.get_string_width(k+" : "+v[0])+2 for k, v in vals[i:i+3]]))
+
             for k, v in vals[i:i+2]:
-                self.set_font(self.lightFont, '', 10)
-                self.cell(self.get_string_width(k+" : "), 4.5, txt=k+": ", border=self.border_val, ln=0, align="L")
-                self.set_font(self.regularFont, '', 10)
-                self.cell(ot-self.get_string_width(k+" : "), 4.5, txt=v[0], border=self.border_val, ln=0, align="R", link=v[1])
-                self.cell(14, 4.5, txt="", border=self.border_val, ln=0, align="R")
+                self.set_font(self.lightFont, '', self.links_text_size)
+                self.cell(self.get_string_width(k+" : ")+2, 4.5, txt=k+": ", border=self.border_val, ln=0, align="L")
+                self.set_font(self.regularFont, '', self.links_text_size)
+                self.set_text_color(*self.heading_color)
+                self.cell(self.get_string_width(v[0]), 4.5, txt=v[0], border=self.border_val, ln=0, align="R", link=v[1])
+                self.cell(gap, 4.5, txt="", border=self.border_val, ln=0, align="R")
+                self.set_text_color(0, 0, 0)
 
             for k, v in vals[i+2:i+3]:
-                self.set_font(self.lightFont, '', 10)
-                self.cell(self.get_string_width(k+" : "), 4.5, txt=k+": ", border=self.border_val, ln=0, align="L")
-                self.set_font(self.regularFont, '', 10)
-                self.cell(ot-self.get_string_width(k+" : "), 4.5, txt=v[0], border=self.border_val, ln=0, align="R", link=v[1])
+                self.set_font(self.lightFont, '', self.links_text_size)
+                self.cell(self.get_string_width(k+" : ")+2, 4.5, txt=k+": ", border=self.border_val, ln=0, align="L")
+                self.set_font(self.regularFont, '', self.links_text_size)
+                self.set_text_color(*self.heading_color)
+                self.cell(self.get_string_width(v[0]), 4.5, txt=v[0], border=self.border_val, ln=0, align="R", link=v[1])
+                self.set_text_color(0, 0, 0)
 
             self.ln()
 
@@ -186,19 +215,21 @@ class TwoColumnTemplate(FPDF):
         self.create_head(pos, "Education")
         for institute, details in education:
             self.initPositionX(pos)
-            self.set_font(self.regularFont, '', 11)
+            self.set_font(self.regularFont, '', self.main_text_size)
             self.multi_cell(self.get_wid(pos), 5, txt=institute, border=self.border_val, align="L")
             self.ln(0.5)
 
-            self.set_font(self.lightFont, '', 10)
+            self.set_font(self.lightFont, '', self.medium_text_size)
             for tl in ["degree", "dates"]:
                 self.initPositionX(pos)
                 self.multi_cell(self.get_wid(pos), 4, txt=details[tl], border=self.border_val, align="L")
-                self.set_font(self.lightFont, '', 9)
+                self.ln(0)
+                self.set_font(self.lightFont, '', self.desc_text_size)
 
             if "other_info" in details:
                 self.initPositionX(pos)
                 self.multi_cell(self.get_wid(pos), 4.5, txt=details['other_info'], border=self.border_val, align="L")
+                self.ln(0)
 
             self.ln(2)
         self.ln(3)
@@ -212,11 +243,12 @@ class TwoColumnTemplate(FPDF):
         self.create_head(pos, "Skills")
         for k, v in skillset.items():
             self.initPositionX(pos)
-            self.set_font(self.regularFont, '', 11)
+            self.set_font(self.regularFont, '', self.main_text_size)
             self.multi_cell(self.get_wid(pos), 6, txt=k, border=self.border_val, align="L")
+            self.ln(0)
 
             self.initPositionX(pos)
-            self.set_font(self.lightFont, '', 10)
+            self.set_font(self.lightFont, '', self.medium_text_size)
             self.multi_cell(self.get_wid(pos), 5, txt=v, border=self.border_val, align="L")
             self.ln(1)
 
@@ -229,7 +261,7 @@ class TwoColumnTemplate(FPDF):
         "Add Certifications"
 
         self.create_head(pos, "Certifications")
-        self.set_font(self.regularFont, '', 10)
+        self.set_font(self.regularFont, '', self.medium_text_size)
         for k in certs:
             self.initPositionX(pos)
             self.insert_bullet(5)
@@ -247,17 +279,17 @@ class TwoColumnTemplate(FPDF):
         self.create_head(pos, "Projects")
         for k, v in projects.items():
             self.initPositionX(pos)
-            self.set_font(self.regularFont, '', 11)
-            # self.insert_bullet(5.5)
+            self.set_font(self.regularFont, '', self.main_text_size)
             self.cell(self.get_wid(pos)-36, 5.5, txt=k, border=self.border_val, ln=0, align="L")
             self.set_font(self.lightItalicFont, '', 9)
             self.cell(36, 5.5, txt=v[0], border=self.border_val, ln=1, align="R")
 
-            self.set_font(self.lightFont, '', 10)
+            self.set_font(self.lightFont, '', self.desc_text_size)
             for x in v[1:]:
                 self.initPositionX(pos)
-                self.insert_bullet(5)
-                self.multi_cell(self.get_wid(pos)-self.indent_wid, 5, txt=x, border=self.border_val, align="L")
+                self.insert_bullet(4.5)
+                self.multi_cell(self.get_wid(pos)-self.indent_wid, 4.5, txt=x, border=self.border_val, align="L")
+                self.ln(0)
 
             self.ln(3)
         self.ln(2)
@@ -271,23 +303,25 @@ class TwoColumnTemplate(FPDF):
         self.create_head(pos, "Work Experience")
         for k, v in work:
             self.initPositionX(pos)
-            self.set_font(self.regularFont, '', 11)
+            self.set_font(self.regularFont, '', self.main_text_size)
             self.cell(self.get_wid(pos)-36, 5, txt=k, border=self.border_val, ln=0, align="L")
-            self.set_font(self.lightItalicFont, '', 9)
+            self.set_font(self.lightItalicFont, '', self.desc_text_size)
             self.cell(36, 5, txt=v[0], border=self.border_val, ln=1, align="R")
 
             self.ln(0.5)
 
             if 'Org' in v[1]:
                 self.initPositionX(pos)
-                self.set_font(self.regularFont, '', 10)
+                self.set_font(self.regularFont, '', self.medium_text_size)
                 self.multi_cell(self.get_wid(pos), 5, txt=v[1]['Org'], border=self.border_val, align="L")
+                self.ln(0)
 
             for x in v[1].get('Desc', []):
                 self.initPositionX(pos)
-                self.set_font(self.lightFont, '', 10)
-                self.insert_bullet(5)
-                self.multi_cell(self.get_wid(pos)-self.indent_wid, 5, txt=x, border=self.border_val, align="L")
+                self.set_font(self.lightFont, '', self.desc_text_size)
+                self.insert_bullet(4.5)
+                self.multi_cell(self.get_wid(pos)-self.indent_wid, 4.5, txt=x, border=self.border_val, align="L")
+                self.ln(0)
 
             self.ln(3)
         self.ln(2)
@@ -299,7 +333,7 @@ class TwoColumnTemplate(FPDF):
         "Add Achievements"
 
         self.create_head(pos, "Achievements")
-        self.set_font(self.regularFont, '', 10)
+        self.set_font(self.regularFont, '', self.medium_text_size)
         for k in achievements:
             self.initPositionX(pos)
             self.insert_bullet(5)
@@ -316,7 +350,7 @@ class TwoColumnTemplate(FPDF):
 
         self.create_head(pos, "Interests")
         self.initPositionX(pos)
-        self.set_font(self.lightFont, '', 10)
+        self.set_font(self.lightFont, '', self.medium_text_size)
         self.multi_cell(self.get_wid(pos), 5, txt=", ".join(interests), border=self.border_val, align="L")
         self.ln(4)
 
@@ -343,20 +377,31 @@ class SingleColumnTemplate(FPDF):
         self.main_wid = self.ttl_wid
         self.hr_sep_pos = 32
         self.indent_wid = 4
-        self.underline_heads = ''
         self.name_size = 32
         self.heading_size = 14
         self.heading_height = 11
+        self.main_text_size = 11
+        self.medium_text_size = 10
+        self.desc_text_size = 9
+        self.links_text_size = 10
         self.border_val = 0
+        self.underline_heads = ''
+        self.head_lines = True
+        self.capitalize_head = True
+        self.heading_color = (10, 77, 122)
         self.add_page()
 
-        # Add fonts
-        self.add_font('Ubuntu-LightItalic', '', os.path.join(BASE_DIR, 'TrashFiles/fonts/Ubuntu/Ubuntu-LightItalic.ttf'), uni=True)
-        self.add_font('Ubuntu-Light', '', os.path.join(BASE_DIR, 'TrashFiles/fonts/Ubuntu/Ubuntu-Light.ttf'), uni=True)
-        self.add_font('Ubuntu', '', os.path.join(BASE_DIR, 'TrashFiles/fonts/Ubuntu/Ubuntu-Regular.ttf'), uni=True)
+        # Add ubuntu fonts
+        self.add_font('Ubuntu-LightItalic', '', os.path.join(BASE_DIR, 'resumify/fonts/Ubuntu/Ubuntu-LightItalic.ttf'), uni=True)
+        self.add_font('Ubuntu-Light', '', os.path.join(BASE_DIR, 'resumify/fonts/Ubuntu/Ubuntu-Light.ttf'), uni=True)
+        self.add_font('Ubuntu-Bold', '', os.path.join(BASE_DIR, 'resumify/fonts/Ubuntu/Ubuntu-Bold.ttf'), uni=True)
+        self.add_font('Ubuntu-Medium', '', os.path.join(BASE_DIR, 'resumify/fonts/Ubuntu/Ubuntu-Medium.ttf'), uni=True)
+        self.add_font('Ubuntu', '', os.path.join(BASE_DIR, 'resumify/fonts/Ubuntu/Ubuntu-Regular.ttf'), uni=True)
 
         # Set fonts
         self.lightFont = 'Ubuntu-Light'
+        self.boldFont = 'Ubuntu-Bold'
+        self.mediumFont = 'Ubuntu-Medium'
         self.lightItalicFont = 'Ubuntu-LightItalic'
         self.regularFont = 'Ubuntu'
 
@@ -372,14 +417,20 @@ class SingleColumnTemplate(FPDF):
     def create_head(self, title):
         "Inserts heading to the page"
 
-        self.set_text_color(30, 30, 90)
-        self.set_draw_color(30, 30, 90)
-        self.set_line_width(0.3)
+        if self.capitalize_head is True:
+            title = title.upper()
+        else:
+            title = title.title()
 
-        self.set_font(self.regularFont, self.underline_heads, self.heading_size)
-        self.cell(self.main_wid, self.heading_height, txt=title.title(), border=self.border_val, ln=1, align="L")
+        self.set_text_color(*self.heading_color)
+        self.set_draw_color(*self.heading_color)
+        self.set_line_width(0.3)
+        self.set_font(self.mediumFont, self.underline_heads, self.heading_size)
+
+        self.cell(self.main_wid, self.heading_height, txt=title, border=self.border_val, ln=1, align="L")
         self.main_y = self.get_y()
-        self.line(10+self.get_string_width(title)+3, self.get_y()-4.4, self.ttl_wid+10, self.get_y()-4.4)
+        if self.head_lines:
+            self.line(10+self.get_string_width(title)+3, self.get_y()-4.4, self.ttl_wid+10, self.get_y()-4.4)
 
         self.set_text_color(0, 0, 0)
 
@@ -421,22 +472,31 @@ class SingleColumnTemplate(FPDF):
         "Add links to your profiles on Github, LinkedIn, Twitter or your personal website"
 
         self.set_y(self.hr_sep_pos+0.5)
-        ot = self.main_wid/3 - 9
+        ot = self.main_wid/3 - 11
         vals = list(links.items())
 
         for i in range(0, len(vals), 3):
+            if len(vals[i:i+3]) > 1:
+                gap = (self.ttl_wid - sum([self.get_string_width(k+" : "+v[0])+2 for k, v in vals[i:i+3]]))/(len(vals[i:i+3])-1)
+            else:
+                gap = (self.ttl_wid - sum([self.get_string_width(k+" : "+v[0])+2 for k, v in vals[i:i+3]]))
+
             for k, v in vals[i:i+2]:
-                self.set_font(self.lightFont, '', 10)
-                self.cell(self.get_string_width(k+" : "), 4.5, txt=k+": ", border=self.border_val, ln=0, align="L")
-                self.set_font(self.regularFont, '', 10)
-                self.cell(ot-self.get_string_width(k+" : "), 4.5, txt=v[0], border=self.border_val, ln=0, align="R", link=v[1])
-                self.cell(14, 4.5, txt="", border=self.border_val, ln=0, align="R")
+                self.set_font(self.lightFont, '', self.links_text_size)
+                self.cell(self.get_string_width(k+" : ")+2, 4.5, txt=k+": ", border=self.border_val, ln=0, align="L")
+                self.set_font(self.regularFont, '', self.links_text_size)
+                self.set_text_color(*self.heading_color)
+                self.cell(self.get_string_width(v[0]), 4.5, txt=v[0], border=self.border_val, ln=0, align="R", link=v[1])
+                self.cell(gap, 4.5, txt="", border=self.border_val, ln=0, align="R")
+                self.set_text_color(0, 0, 0)
 
             for k, v in vals[i+2:i+3]:
-                self.set_font(self.lightFont, '', 10)
-                self.cell(self.get_string_width(k+" : "), 4.5, txt=k+": ", border=self.border_val, ln=0, align="L")
-                self.set_font(self.regularFont, '', 10)
-                self.cell(ot-self.get_string_width(k+" : "), 4.5, txt=v[0], border=self.border_val, ln=0, align="R", link=v[1])
+                self.set_font(self.lightFont, '', self.links_text_size)
+                self.cell(self.get_string_width(k+" : ")+2, 4.5, txt=k+": ", border=self.border_val, ln=0, align="L")
+                self.set_font(self.regularFont, '', self.links_text_size)
+                self.set_text_color(*self.heading_color)
+                self.cell(self.get_string_width(v[0]), 4.5, txt=v[0], border=self.border_val, ln=0, align="R", link=v[1])
+                self.set_text_color(0, 0, 0)
 
             self.ln()
 
@@ -451,15 +511,17 @@ class SingleColumnTemplate(FPDF):
 
         self.create_head("Education")
         for institute, details in education:
-            self.set_font(self.regularFont, '', 11)
+            self.set_font(self.regularFont, '', self.main_text_size)
             self.cell(self.main_wid-20, 5, txt=institute, border=self.border_val, ln=0, align="L")
 
-            self.set_font(self.lightFont, '', 9)
+            self.set_font(self.lightFont, '', self.desc_text_size)
             self.cell(20, 5, txt=details["dates"], border=self.border_val, ln=1, align="L")
-            self.multi_cell(self.main_wid, 4.5, txt=details["degree"], border=self.border_val, align="L")
+            self.set_font(self.lightFont, '', self.medium_text_size)
+            self.cell(self.main_wid, 4.5, txt=details["degree"], border=self.border_val, ln=1, align="L")
 
+            self.set_font(self.lightFont, '', self.desc_text_size)
             if "other_info" in details:
-                self.multi_cell(self.main_wid, 4.5, txt=details['other_info'], border=self.border_val, align="L")
+                self.cell(self.main_wid, 4.5, txt=details['other_info'], border=self.border_val, ln=1, align="L")
 
             self.ln(2)
         self.ln(1)
@@ -470,12 +532,13 @@ class SingleColumnTemplate(FPDF):
 
         self.create_head("Skills")
         for k, v in skillset.items():
-            self.set_font(self.regularFont, '', 10)
+            self.set_font(self.regularFont, '', self.medium_text_size)
             self.insert_bullet(5)
             self.cell((self.main_wid)*.3-self.indent_wid, 5, txt=k, border=self.border_val, ln=0, align="L")
 
-            self.set_font(self.lightFont, '', 10)
+            self.set_font(self.lightFont, '', self.medium_text_size)
             self.multi_cell((self.main_wid)*.7, 5, txt=v, border=self.border_val, align="R")
+            self.ln(0)
 
         self.ln(3)
 
@@ -485,18 +548,19 @@ class SingleColumnTemplate(FPDF):
 
         self.create_head("Projects")
         for k, v in projects.items():
-            self.set_font(self.regularFont, '', 11)
+            self.set_font(self.regularFont, '', self.main_text_size)
             self.cell(self.main_wid-36, 5, txt=k, border=self.border_val, ln=0, align="L")
 
-            self.set_font(self.lightItalicFont, '', 9)
+            self.set_font(self.lightItalicFont, '', self.desc_text_size)
             self.cell(36, 5, txt=v[0], border=self.border_val, ln=1, align="R")
 
-            self.set_font(self.lightFont, '', 10)
+            self.set_font(self.lightFont, '', self.desc_text_size)
             for x in v[1:]:
                 self.insert_bullet(4.5)
                 self.multi_cell(self.main_wid-self.indent_wid, 4.5, txt=x, border=self.border_val, align="L")
+                self.ln(0)
 
-            self.ln(3)
+            self.ln(2)
         self.ln(1)
 
     @updatePosition1
@@ -505,21 +569,23 @@ class SingleColumnTemplate(FPDF):
 
         self.create_head("Work Experience")
         for k, v in work:
-            self.set_font(self.regularFont, '', 11)
+            self.set_font(self.regularFont, '', self.main_text_size)
             self.cell(self.main_wid-36, 5, txt=k, border=self.border_val, ln=0, align="L")
-            self.set_font(self.lightItalicFont, '', 9)
+            self.set_font(self.lightItalicFont, '', self.desc_text_size)
             self.cell(36, 5, txt=v[0], border=self.border_val, ln=1, align="R")
 
             if 'Org' in v[1]:
-                self.set_font(self.regularFont, '', 10)
+                self.set_font(self.regularFont, '', self.medium_text_size)
                 self.multi_cell(self.main_wid, 5, txt=v[1]['Org'], border=self.border_val, align="L")
+                self.ln(0)
 
             for x in v[1].get('Desc', []):
-                self.set_font(self.lightFont, '', 10)
+                self.set_font(self.lightFont, '', self.desc_text_size)
                 self.insert_bullet(4.5)
                 self.multi_cell(self.main_wid-self.indent_wid, 4.5, txt=x, border=self.border_val, align="L")
+                self.ln(0)
 
-            self.ln(3)
+            self.ln(2)
         self.ln(1)
 
     @updatePosition1
@@ -527,10 +593,11 @@ class SingleColumnTemplate(FPDF):
         "Add Certifications"
 
         self.create_head("Certifications")
-        self.set_font(self.regularFont, '', 10)
+        self.set_font(self.regularFont, '', self.medium_text_size)
         for k in certs:
             self.insert_bullet(5)
             self.multi_cell(self.main_wid-self.indent_wid, 5, txt=k, border=self.border_val, align="L")
+            self.ln(0)
 
         self.ln(3)
 
@@ -539,10 +606,11 @@ class SingleColumnTemplate(FPDF):
         "Add Achievements"
 
         self.create_head("Achievements")
-        self.set_font(self.regularFont, '', 10)
+        self.set_font(self.regularFont, '', self.medium_text_size)
         for k in achievements:
             self.insert_bullet(5)
             self.multi_cell(self.main_wid-self.indent_wid, 5, txt=k, border=self.border_val, align="L")
+            self.ln(0)
 
         self.ln(3)
 
@@ -551,7 +619,7 @@ class SingleColumnTemplate(FPDF):
         "Add your Interests"
 
         self.create_head("Interests")
-        self.set_font(self.lightFont, '', 10)
+        self.set_font(self.lightFont, '', self.medium_text_size)
         self.multi_cell(self.main_wid, 5, txt=", ".join(interests), border=self.border_val, align="L")
         self.ln(3)
 
